@@ -1,7 +1,7 @@
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class FormDesignerConfig(AppConfig):
-    name = 'form_designer'
+    name = "form_designer"
     verbose_name = _("Form Designer")
